@@ -1191,7 +1191,7 @@ def stats_for_dataset_metadata(stns):
     if type1 in ['Polygon', 'Line']:
         geo = [s['geometry']['coordinates'][0][0][-1] for s in stns]
     else:
-        geo = [s['geometry']['coordinates'][0][-1] for s in stns]
+        geo = [s['geometry']['coordinates'][-1] for s in stns]
 
     geo1 = np.array(geo).round(5)
     geo1.sort()
