@@ -16,7 +16,7 @@ from multiprocessing.pool import ThreadPool, Pool
 from tethysts.utils import key_patterns, get_object_s3, s3_connection, read_json_zstd, read_pkl_zstd
 from tethys_utils.misc import make_run_date_key, write_json_zstd, write_pkl_zstd
 # from misc import make_run_date_key, write_json_zstd, write_pkl_zstd
-from tethys_utils.processing import compare_xrs, process_station_summ
+from tethys_utils.processing import compare_xrs, process_station_summ, stats_for_dataset_metadata
 # from processing import compare_xrs, process_station_summ
 from datetime import date, datetime
 
@@ -147,7 +147,7 @@ def list_object_versions_s3(s3_client, bucket, prefix, next_key='', delimiter=No
     return f_df1
 
 
-def put_remote_dataset(s3, bucket, dataset, run_date=None):
+def put_remote_dataset(s3, bucket, dataset, stns, run_date=None):
     """
 
     """
@@ -155,6 +155,14 @@ def put_remote_dataset(s3, bucket, dataset, run_date=None):
 
     dataset_id = dataset['dataset_id']
 
+    ## generate stats for the dataset metadata
+    ds_stats = stats_for_dataset_metadata(stns)
+
+    if dataset['spatial_distribution'] == 'sparse':
+        ds_stats.pop('spatial_resolution')
+
+    dataset.update(ds_stats)
+
     ds4 = Dataset(**dataset)
 
     ds5 = orjson.loads(ds4.json(exclude_none=True))
@@ -255,12 +263,25 @@ def put_remote_agg_stations(s3, bucket, dataset_id, threads=30):
 
     output = ThreadPool(threads).starmap(get_remote_station, stn_list)
 
+    ## Separate the results obj keys from the stations
+    results_obj_keys = [{'dataset_id': s['dataset_id'], 'station_id': s['station_id'], 'results_object_key': s['results_object_key']} for s in output]
+    [s.update({'results_object_key': s['results_object_key'][-1]}) for s in output]
+
+    ## Save files
+    # Stations
     stns_obj = write_json_zstd(output)
 
     run_date_key = make_run_date_key()
     stns_key = agg_stn_key.format(dataset_id=dataset_id)
     s3.put_object(Body=stns_obj, Bucket=bucket, Key=stns_key, ContentType='application/json', Metadata={'run_date': run_date_key})
 
+    # Results object keys
+    ro_key = key_patterns['results_object_keys'].format(dataset_id=dataset_id)
+
+    ro_obj = write_json_zstd(results_obj_keys)
+
+    s3.put_object(Body=ro_obj, Bucket=bucket, Key=ro_key, ContentType='application/json', Metadata={'run_date': run_date_key})
+
     return output
 
 
